Index: get-backtrace.lisp
===================================================================
--- get-backtrace.lisp	(revision 43)
+++ get-backtrace.lisp	(working copy)
@@ -129,4 +129,33 @@
     #-:hunchentoot-sbcl-debug-print-variable-alist
     (let ((sb-debug:*debug-print-level* nil)
           (sb-debug:*debug-print-length* nil))
-      (sb-debug:backtrace most-positive-fixnum s))))
\ No newline at end of file
+      (sb-debug:backtrace most-positive-fixnum s))))
+
+#+ecl
+(defun get-backtrace (error)
+  "This is the function that is used internally by Hunchentoot to
+show or log backtraces.  It accepts a condition object ERROR and
+returns a string with the corresponding backtrace."
+  (declare (ignore error))
+  (let* ((si::*tpl-commands* si::tpl-commands)
+         (si::*ihs-top* (si::ihs-top 'call-with-debugging-environment))
+	 (si::*ihs-current* si::*ihs-top*)
+	 (si::*frs-base* (or (si::sch-frs-base si::*frs-top* si::*ihs-base*) (1+ (si::frs-top))))
+	 (si::*frs-top* (si::frs-top))
+	 (si::*read-suppress* nil)
+	 (si::*tpl-level* (1+ si::*tpl-level*))
+	 (backtrace (loop for ihs from si::*ihs-base* below si::*ihs-top*
+			  collect (list (si::ihs-fun ihs)
+					(si::ihs-env ihs)
+					nil))))
+    (loop for f from si::*frs-base* until si::*frs-top*
+	  do (let ((i (- (si::frs-ihs f) si::*ihs-base* 1)))
+	       (when (plusp i)
+		 (let* ((x (elt backtrace i))
+			(name (si::frs-tag f)))
+		   (unless (fixnump name)
+		     (push name (third x)))))))
+    (setf backtrace (nreverse backtrace))
+    (with-output-to-string (stream)
+      (dolist (i backtrace)
+	(format stream "~A~%" (car i))))))
